Index: src/execution.cc |
diff --git a/src/execution.cc b/src/execution.cc |
index 690a4e3f4e6cd8570a0b052ee643b8fedb24aa69..6598ebe0f48bdf527923dad4e0bfbe70680461f2 100644 |
--- a/src/execution.cc |
+++ b/src/execution.cc |
@@ -163,9 +163,9 @@ Handle<Object> Execution::Call(Isolate* isolate, |
} |
Handle<JSFunction> func = Handle<JSFunction>::cast(callable); |
// In non-strict mode, convert receiver. |
if (convert_receiver && !receiver->IsJSReceiver() && |
- !func->shared()->native() && func->shared()->is_classic_mode()) { |
+ !func->shared()->native() && func->shared()->is_sloppy_mode()) { |
if (receiver->IsUndefined() || receiver->IsNull()) { |
Object* global = func->context()->global_object()->global_receiver(); |
// Under some circumstances, 'global' can be the JSBuiltinsObject |
@@ -163,9 +163,9 @@ Handle<Object> Execution::Call(Isolate* isolate, |
} |
Handle<JSFunction> func = Handle<JSFunction>::cast(callable); |
- // In non-strict mode, convert receiver. |
+ // In sloppy mode, convert receiver. |
if (convert_receiver && !receiver->IsJSReceiver() && |